locapip是一个支持远程调用的工具集，支持医学影像、工业设计等场景数据的管理和编辑。

## contact

email: <88172828@qq.com>

## done

- 基于fastapi和uvicorn，实现RESTful API远程调用Python方法
- 基于vcpkg和pybind11，实现Python调用C++方法处理场景数据
- 基于Unreal Engine，实现跨平台的次世代场景交互

## todo

- 基于Omniverse，实现物理模拟和影视渲染